import java.awt.*;
import java.awt.event.*;

/** An ImageButtonListener that reacts to 
 * mousePressed/mouseClicked events exactly as a 
 * java.awt.Button does.<p>
 *
 * @version 1.0, Apr 1 1996
 * @version 1.1, Nov 8 1996
 *
 *  Took out check for right-mouse button; mouse events are
 *  handled no matter which mouse button initiated the event.
 *
 * @version 1.2, Dec 20, 1996
 *
 *  Refactored for the new event handling model.
 *
 * @author  David Geary
 * @see   ImageButton
 * @see   ImageButtonListener
 * @see   StickyImageButtonListener
 */

public class SpringyImageButtonListener extends ImageButtonListener {

    public void activate (ImageButton ib) {
        disarm (ib);

        if (ib instanceof PushImageButton)
            ((PushImageButton)ib).processAction ();
    }

    public void arm (ImageButton ib) {
        ib.paintInset ();
        button_armed = true;
    }

    public void disarm (ImageButton ib) {
        ib.paintRaised ();
        button_armed = false;
    }
}
